import React from 'react';
import SvgIcon from './SvgIcon';

/**
 * 搜索栏组件
 * @param {Object} props
 * @param {string} props.searchKeyword - 搜索关键词
 * @param {boolean} props.isSearching - 是否正在搜索
 * @param {Function} props.onSearchChange - 搜索关键词变化的回调函数
 * @param {Function} props.onSearch - 提交搜索的回调函数
 * @param {Function} props.onClearSearch - 清除搜索的回调函数
 * @param {string} props.placeholder - 搜索框占位文本
 * @param {string} props.className - 额外的 CSS 类名
 */
const SearchBar = ({
    searchKeyword,
    isSearching,
    onSearchChange,
    onSearch,
    onClearSearch,
    placeholder = '搜索...',
    className = 'w-50',
}) => {
    return (
        <form className={`d-flex ${className}`} onSubmit={onSearch}>
            <input
                type='text'
                className='form-control'
                placeholder={placeholder}
                value={searchKeyword}
                onChange={onSearchChange}
            />
            {isSearching && (
                <button type='button' className='btn btn-outline-dark ms-2' onClick={onClearSearch}>
                    清除
                </button>
            )}
        </form>
    );
};

export default SearchBar;
