import React, { useEffect } from 'react';
import { useSelector } from 'react-redux';
import { useNavigate } from 'react-router-dom';
import PendingRequests from './components/PendingRequests';
import UserPermissions from './components/UserPermissions';
import ApiModeSwitch from '../../components/ApiModeSwitch';
import './Permissions.css';

export default function PermissionsPage() {
    const navigate = useNavigate();
    const { user } = useSelector((state) => state.auth);

    // 检查用户是否有管理权限（leader 或 admin）
    useEffect(() => {
        if (!user || (user.role !== 'leader' && user.role !== 'admin')) {
            navigate('/');
        }
    }, [user, navigate]);

    return (
        <div className='permissions-container'>
            <div className='api-mode-control mb-3'>
                <ApiModeSwitch />
            </div>
            
            <div className='permissions-section mb-4'>
                <PendingRequests />
            </div>
            
            <div className='permissions-section'>
                <UserPermissions />
            </div>
        </div>
    );
}
