import { createSlice } from '@reduxjs/toolkit';
import { fetchPermissionsThunk, approvePermissionThunk, rejectPermissionThunk } from './permissions.thunks';

const initialState = {
    permissions: {
        items: [],
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
    },
    approveReject: {
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
        currentId: null,
    },
};

const permissionsSlice = createSlice({
    name: 'permissions',
    initialState,
    reducers: {
        resetApproveRejectStatus: (state) => {
            state.approveReject = {
                status: 'idle',
                error: null,
                currentId: null,
            };
        },
    },
    extraReducers: (builder) => {
        // 获取权限申请列表
        builder
            .addCase(fetchPermissionsThunk.pending, (state) => {
                state.permissions.status = 'loading';
                state.permissions.error = null;
            })
            .addCase(fetchPermissionsThunk.fulfilled, (state, action) => {
                state.permissions.status = 'succeeded';
                state.permissions.items = action.payload;
            })
            .addCase(fetchPermissionsThunk.rejected, (state, action) => {
                state.permissions.status = 'failed';
                state.permissions.error = action.payload || '获取权限申请列表失败';
            });

        // 批准权限申请
        builder
            .addCase(approvePermissionThunk.pending, (state, action) => {
                state.approveReject.status = 'loading';
                state.approveReject.error = null;
                state.approveReject.currentId = action.meta.arg.id;
            })
            .addCase(approvePermissionThunk.fulfilled, (state, action) => {
                state.approveReject.status = 'succeeded';
                // 从列表中移除已批准的申请
                state.permissions.items = state.permissions.items.filter((item) => item.id !== action.meta.arg.id);
            })
            .addCase(approvePermissionThunk.rejected, (state, action) => {
                state.approveReject.status = 'failed';
                state.approveReject.error = action.payload || '批准权限申请失败';
            });

        // 拒绝权限申请
        builder
            .addCase(rejectPermissionThunk.pending, (state, action) => {
                state.approveReject.status = 'loading';
                state.approveReject.error = null;
                state.approveReject.currentId = action.meta.arg.id;
            })
            .addCase(rejectPermissionThunk.fulfilled, (state, action) => {
                state.approveReject.status = 'succeeded';
                // 从列表中移除已拒绝的申请
                state.permissions.items = state.permissions.items.filter((item) => item.id !== action.meta.arg.id);
            })
            .addCase(rejectPermissionThunk.rejected, (state, action) => {
                state.approveReject.status = 'failed';
                state.approveReject.error = action.payload || '拒绝权限申请失败';
            });
    },
});

export const { resetApproveRejectStatus } = permissionsSlice.actions;

export default permissionsSlice.reducer;
