import { createAsyncThunk } from '@reduxjs/toolkit';
import { get, post } from '../../services/api';

// 获取权限申请列表
export const fetchPermissionsThunk = createAsyncThunk(
    'permissions/fetchPermissions',
    async (_, { rejectWithValue }) => {
        try {
            const response = await get('/permissions/');
            return response || [];
        } catch (error) {
            console.error('获取权限申请列表失败:', error);
            return rejectWithValue('获取权限申请列表失败');
        }
    }
);

// 批准权限申请
export const approvePermissionThunk = createAsyncThunk(
    'permissions/approvePermission',
    async ({ id, responseMessage }, { rejectWithValue }) => {
        try {
            const response = await post(`/permissions/${id}/approve/`, {
                response_message: responseMessage || '已批准',
            });
            return response;
        } catch (error) {
            console.error('批准权限申请失败:', error);
            return rejectWithValue('批准权限申请失败');
        }
    }
);

// 拒绝权限申请
export const rejectPermissionThunk = createAsyncThunk(
    'permissions/rejectPermission',
    async ({ id, responseMessage }, { rejectWithValue }) => {
        try {
            const response = await post(`/permissions/${id}/reject/`, {
                response_message: responseMessage || '已拒绝',
            });
            return response;
        } catch (error) {
            console.error('拒绝权限申请失败:', error);
            return rejectWithValue('拒绝权限申请失败');
        }
    }
);
